==> codeready-workspaces-2.6.0-GA-crwctl3-sources.tar.gz: crwctl/lib/common-flags.d.ts <==
export declare const cheNamespace: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const devWorkspaceControllerNamespace: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const cheDeployment: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const listrRenderer: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const ACCESS_TOKEN_KEY = "access-token";
export declare const accessToken: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const skipKubeHealthzCheck: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
export declare const CHE_API_ENDPOINT_KEY = "che-api-endpoint";
export declare const cheApiEndpoint: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const CHE_OPERATOR_CR_PATCH_YAML_KEY = "che-operator-cr-patch-yaml";
export declare const cheOperatorCRPatchYaml: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const assumeYes: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
export declare const CHE_OPERATOR_CR_YAML_KEY = "che-operator-cr-yaml";
export declare const cheOperatorCRYaml: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const USERNAME_KEY = "username";
export declare const username: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const K8SPODWAITTIMEOUT_KEY = "k8spodwaittimeout";
export declare const k8sPodWaitTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const K8SPODDOWNLOADIMAGETIMEOUT_KEY = "k8spoddownloadimagetimeout";
export declare const k8sPodDownloadImageTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const K8SPODREADYTIMEOUT_KEY = "k8spodreadytimeout";
export declare const k8sPodReadyTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const K8SPODERRORRECHECKTIMEOUT_KEY = "k8spoderrorrechecktimeout";
export declare const k8sPodErrorRecheckTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const LOG_DIRECTORY_KEY = "directory";
export declare const logsDirectory: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const CHE_TELEMETRY: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;

==> codeready-workspaces-2.7.0-GA-crwctl3-sources.tar.gz: crwctl/lib/common-flags.d.ts <==
export declare const cheNamespace: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const devWorkspaceControllerNamespace: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const batch: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
export declare const cheDeployment: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const listrRenderer: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const ACCESS_TOKEN_KEY = "access-token";
export declare const accessToken: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const skipKubeHealthzCheck: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
export declare const CHE_API_ENDPOINT_KEY = "che-api-endpoint";
export declare const cheApiEndpoint: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const CHE_OPERATOR_CR_PATCH_YAML_KEY = "che-operator-cr-patch-yaml";
export declare const cheOperatorCRPatchYaml: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const assumeYes: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
export declare const CHE_OPERATOR_CR_YAML_KEY = "che-operator-cr-yaml";
export declare const cheOperatorCRYaml: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const USERNAME_KEY = "username";
export declare const username: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const K8SPODWAITTIMEOUT_KEY = "k8spodwaittimeout";
export declare const k8sPodWaitTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const K8SPODDOWNLOADIMAGETIMEOUT_KEY = "k8spoddownloadimagetimeout";
export declare const k8sPodDownloadImageTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const K8SPODREADYTIMEOUT_KEY = "k8spodreadytimeout";
export declare const k8sPodReadyTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const K8SPODERRORRECHECKTIMEOUT_KEY = "k8spoderrorrechecktimeout";
export declare const k8sPodErrorRecheckTimeout: import("@oclif/parser/lib/flags").IOptionFlag<string>;
export declare const LOG_DIRECTORY_KEY = "directory";
export declare const logsDirectory: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const CHE_TELEMETRY: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
export declare const DEPLOY_VERSION_KEY = "version";
export declare const cheDeployVersion: import("@oclif/parser/lib/flags").IOptionFlag<string | undefined>;
